#!/bin/bash

print_help_en() {
cat <<EOF
Usage: $(basename $0) [KEY]...
Creates new fly-kiosk profile for users that have old kiosk.
It copies .desktop files from ~/Desktop/Desktop1 to /etc/fly-kiosk
It does NOT turn off user's old kiosk.

  -u, --user <user>          create kiosk profile for <user> if he has old kiosk
  -a, --all                  create kiosk profile for all users that have old kiosk
  -f, --force                force kiosk profile creation even if user hasn't got old kiosk
                             overwrite kiosk profile even if user already has one
                             can't use with --all argument
  -h, --help                 show this help

EOF
}

print_help_ru() {
cat <<EOF
Использование: $(basename $0) [КЛЮЧ]...
Создает новый профиль для киоска для пользователей со старым киоском.
Копирует .desktop файлы из ~/Desktop/Desktop1 в /etc/fly-kiosk
НЕ выключает старый киоск у пользователя.

  -u, --user <user>          создать профиль киоска для <user> если у него есть старый киоск
  -a, --all                  создать профиль киоска для всех пользователей если у них есть старый киоск
  -f, --force                создать профиль киоска даже если у пользователя нет старого киоска
                             перезаписать профиль киоска если у пользователя он уже есть
                             нельзя использовать с аргументом --all
  -h, --help                 показать эту справку и выйти

EOF
}

print_help() {
[ "$LANG" = "ru_RU.UTF-8" ] && print_help_ru || print_help_en
}

username=''
allUsers=false
forceCreation=false
kioskOld=/usr/share/fly-kiosk/fly-kiosk
kioskTemplate=/usr/share/fly-kiosk/kiosk_template

stringUserOrAll="You should specify either user or use --all argument"
stringForceAll="You can't use --force argument with --all argument"
stringOldKioskScript="Can't find old kiosk script or it's not executable:"
stringKioskTemplate="Can't find kiosk template"
stringCreating="Creating kiosk profile for user"
stringRemoving="[--force] Removing previous kiosk profile"
stringAlreadyExist="Error: kiosk profile already exists for user:"
stringForceRemove="Use --force argument or remove it manually"
stringFound="Found .desktop files:"
stringOldKioskUser="Can't find old kiosk for user:"
stringUseForce="You can use --force argument"
stringRoot="Run $(basename $0) from superuser"
stringCantFind="Can't find"

# translate strings
if [ "$LANG" = "ru_RU.UTF-8" ]; then
    stringUserOrAll="Вы должны указать либо пользователя, либо использовать аргумент --all"
    stringForceAll="Вы не можете использовать аргумент --force вместе с --all"
    stringOldKioskScript="Не могу найти скрипт старого киоска или он не исполняемый:"
    stringKioskTemplate="Не могу найти профиль киоска"
    stringCreating="Создание профиля киоска для пользователя"
    stringRemoving="[--force] Удаление предыдущего профиля киоска"
    stringAlreadyExist="Ошибка: профиль киоска уже существует у пользователя:"
    stringForceRemove="Используйте аргумент --force или удалите его вручную"
    stringFound="Найдено .desktop файлов:"
    stringOldKioskUser="Старый киоск не найден у пользователя:"
    stringUseForce="Вы можете использовать аргумент --force"
    stringRoot="Запустите $(basename $0) от суперпользователя"
    stringCantFind="Не могу найти"
fi

while [ -n "$1" ]; do
    case "$1" in
        --user|-u)
            username="$2"
            shift; shift
            ;;
        --all|-a)
            allUsers=true
            shift
            ;;
        --force|-f)
            forceCreation=true
            shift
            ;;
        --help|-h|*)
            print_help
            exit 1
            ;;
    esac
done

if [ -z "$username" ] && [ "$allUsers" = false ]; then
    echo "$stringUserOrAll"
    echo ""
    print_help
    exit 1
fi

if [ -n "$username" ] && [ "$allUsers" = true ]; then
    echo "$stringUserOrAll"
    echo ""
    print_help
    exit 1
fi

if [ "$allUsers" = true ] && [ "$forceCreation" = true ]; then
    echo "$stringForceAll"
    echo ""
    print_help
    exit 1
fi

if [ ! `id -u` = "0" ]; then
    echo "$stringRoot"
    exit 1
fi

if [ ! -x "$kioskOld" ]; then
    echo "$stringOldKioskScript $kioskOld"
    exit 1
fi

if [ ! -d "$kioskTemplate" ]; then
    echo "$stringKioskTemplate $kioskTemplate"
    exit 1
fi

# arg: user
create_kiosk_profile() {
user=$1
echo "$stringCreating $user"

if [ -d "/etc/fly-kiosk/$user" ]; then
    if [ "$forceCreation" = true ]; then
        echo "$stringRemoving"
        rm -rf /etc/fly-kiosk/$user
    else
        echo "$stringAlreadyExist $user"
        echo "$stringForceRemove"
        return 1
    fi
fi

mkdir -p /etc/fly-kiosk
cp -R "$kioskTemplate" "/etc/fly-kiosk/$user"
cp /home/$user/Desktops/Desktop1/*.desktop /etc/fly-kiosk/$user/desktop

for desktopFile in `find /etc/fly-kiosk/$user/desktop -name '*.desktop'`; do
    exec=`cat $desktopFile | grep ^Exec= | cut -c 6-`
    url=`cat $desktopFile | grep ^URL= | cut -c 5-`
    type=`cat $desktopFile | grep ^Type= | cut -c 6-`
    
    # Process Links
    if [ "$type" = "Link" ]; then
        # fly-fm remove :Computer from URL except :Trash
        if [[ "$url" == "fly-fm"* ]] && [ ! "$url" = "fly-fm:Trash" ]; then
            sed -i -e 's/^URL=/#URL=/g' $desktopFile
            sed -i -e 's/^Type=Link/Type=Application/g' $desktopFile
            sed -i -e 's/^Exec=/#Exec=/g' $desktopFile
            type="Link"
            exec="fly-fm"
            echo "Exec=$exec" >> $desktopFile
        elif [ -f "$url" ]; then
            # Link -> Application
            cp "$url" "$desktopFile"
            exec=`cat $desktopFile | grep ^Exec= | cut -c 6-`
            type=`cat $desktopFile | grep ^Type= | cut -c 6-`
        else
            # remove unknown link
            rm $desktopFile
            continue
        fi
    fi
    
    # set absolute path to Exec
    execProc=`echo $exec | awk '{print $1;}'`
    oldpath=$PATH
    PATH=/usr/local/bin:/usr/bin:/bin:/usr/local/games:/usr/games
    execAbs=`which $execProc`
    PATH=$oldpath
    sed -i -e "s|^Exec=$execProc|Exec=$execAbs|g" $desktopFile
    exec=`cat $desktopFile | grep ^Exec= | cut -c 6-`
    
    # rm desktop if Exec is empty
    [ -z "$exec" ] && rm $desktopFile
done

echo "$stringFound `ls -1 /etc/fly-kiosk/$user/desktop | wc -l`"
}

# arg: user
# ret: 0 - false; 1 - true
user_is_in_old_kiosk() {
oldKioskOutput=`$kioskOld --user $1 --status`
[[ $oldKioskOutput == *"is locked"* ]] && return 1 || return 0
}

if [ -n "$username" ]; then
    if [ ! -d "/home/$username" ]; then
        echo "$stringCantFind /home/$username"
        exit 1
    fi
    
    user_is_in_old_kiosk $username
    
    if [ "$?" = 1 ] || [ "$forceCreation" = true ]; then
        create_kiosk_profile $username
    else
        echo "$stringOldKioskUser $username"
        echo "$stringUseForce"
    fi
else
    for user in `ls -1 /home`; do
        user_is_in_old_kiosk $user
        if [ "$?" = 1 ]; then
            create_kiosk_profile $user
        else
            echo "$stringOldKioskUser $user"
        fi
    done
fi


